import { getLogMessage } from './log.header';
export class Logger {
    constructor(className) {
        if (!className) {
            className = 'generic logger';
        }
        this.className = className;
    }
    _log(logType, methodeName, description, object, group = false) {
        const header = getLogMessage(logType, this.className, methodeName, description);
        if (object) {
            console.log(header, object);
        }
        else if (group) {
            console.group(header);
        }
        else {
            console.log(header);
        }
        LogHelper.add(header);
        return this;
    }
    /**
     * Starts log group and logs to console
     * @param {string} methodeName The methods where the logging takes place
     * @param {string} description The log message or description
     */
    group(methodeName, description) {
        return this._log('LOG', methodeName, description, undefined, true);
    }
    groupEnd() {
        console.groupEnd();
        return this;
    }
    /**
     * Logs to the console
     * @param {string} methodeName The methods where the logging takes place
     * @param {string} description The log message or description
     * @param {unknown} object An optional objects which gets printed to the console
     * @return {Logger} Returns logger
     */
    log(methodeName, description, object) {
        return this._log('LOG', methodeName, description, object);
    }
    /**
     * Log info to the console
     * @param {string} methodeName The methods where the logging takes place
     * @param {string} description The log message or description
     * @param {unknown} object An optional objects which gets printed to the console
     * @return {Logger} Returns logger
     */
    info(methodeName, description, object) {
        return this._log('INFO', methodeName, description, object);
    }
    /**
     * Log warning to the console
     * @param {string} methodeName The methods where the logging takes place
     * @param {string} description The log message or description
     * @param {unknown} object An optional objects which gets printed to the console
     * @return {Logger} Returns logger
     */
    warning(methodeName, description, object) {
        return this._log('WARNING', methodeName, description, object);
    }
    /**
     * Log error the console
     * @param {string} methodeName The methods where the logging takes place
     * @param {string} description The log message or description
     * @param {unknown} object An optional objects which gets printed to the console
     * @return {Logger} Returns logger
     */
    error(methodeName, description, object) {
        return this._log('ERROR', methodeName, description, object);
    }
}
export const loggers = new Map();
export let genericLogger;
export function loggerOf(className) {
    if (!className) {
        if (!genericLogger) {
            genericLogger = new Logger(undefined);
        }
        return genericLogger;
    }
    let logger = loggers.get(className);
    if (!logger) {
        logger = new Logger(className);
        loggers.set(className, logger);
    }
    return logger;
}
export class LogHelper {
    static { this.maximalLogSize = 5000; }
    static { this.overflowRemoveCount = 200; }
    static { this.log = []; }
    /**
     * Gets a copy of the log
     * @return {string[]} Copy of the log
     */
    static getLog() {
        return this.log.slice();
    }
    static setLog(log) {
        this.log = log;
    }
    /**
     * Adds a string to the log
     * @param {string} log A string to add to the log
     */
    static add(log) {
        if (this.log.length > this.maximalLogSize) {
            this.log.slice(0, this.overflowRemoveCount);
        }
        this.log.push(log);
    }
    /**
     * Remove a line in the log
     * @param {number} index The line to be removed
     */
    static remove(index) {
        this.log.slice(index, 1);
    }
    /**
     * Removes the complete log
     */
    static removeAll() {
        this.setLog([]);
    }
    /**
     * Gets the log size
     * @return {number} Returns the log size
     */
    static size() {
        return this.log.length;
    }
    /**
     * Checks if entries exists
     * @return {boolean}Returns <code>true</code> if local storage is empty, <code>false</code> if not
     */
    static isEmpty() {
        return this.size() === 0;
    }
    /**
     * Checks if entries exists
     * @return {boolean} Returns <code>false</code> if local storage is empty, <code>true</code> if not
     */
    static hasEntries() {
        return !this.isEmpty();
    }
}
//# sourceMappingURL=logger.js.map